@@ -2,7 +2,7 @@
 # Configuration file for using the xslt library
 #
 XSLT_LIBDIR="-L/usr/local/lib"
-XSLT_LIBS="-lxslt -L/usr/local/lib -lxml2 -lpthread -lz -llzma -liconv -lm "
+XSLT_LIBS="-lxslt -L/usr/local/lib -lxml2 "
 XSLT_PRIVATE_LIBS="-lm"
 XSLT_INCLUDEDIR="-I/usr/local/include"
-MODULE_VERSION="xslt-1.1.35"
+MODULE_VERSION="xslt-1.1.37"
